[Zodb-checkins] CVS: ZODB3/ZEO/tests - zeoserver.py:1.19.4.2

Jeremy Hylton jeremy at zope.com
Wed Sep 10 14:01:03 EDT 2003


Update of /cvs-repository/ZODB3/ZEO/tests
In directory cvs.zope.org:/tmp/cvs-serv17205

Modified Files:
      Tag: ZODB3-3_2-branch
	zeoserver.py 
Log Message:
Change delay until suicide to match upper bound on InvalidationTests.

I'm not sure why the old code did a loop with many small sleeps.  I
changed it to one big sleep.  If this is a mistake, we can change it
back and add an explanatory comment.


=== ZODB3/ZEO/tests/zeoserver.py 1.19.4.1 => 1.19.4.2 ===
--- ZODB3/ZEO/tests/zeoserver.py:1.19.4.1	Fri Jun 20 14:11:01 2003
+++ ZODB3/ZEO/tests/zeoserver.py	Wed Sep 10 13:01:02 2003
@@ -122,9 +122,8 @@
         self._adminaddr = addr
 
     def run(self):
-        # If this process doesn't exit in 100 seconds, commit suicide
-        for i in range(20):
-            time.sleep(5)
+        # If this process doesn't exit in 300 seconds, commit suicide
+        time.sleep(300)
         from ZEO.tests.forker import shutdown_zeo_server
         # XXX If the -k option was given to zeoserver, then the process will
         # go away but the temp files won't get cleaned up.




More information about the Zodb-checkins mailing list